@@ -23,7 +23,7 @@ use vars qw( @ISA $VERSION $ATTRIBUTION $drh $err $errstr $sqlstate );
 
 @ISA =   qw( DBD::File );
 
-$VERSION     = "0.48";
+$VERSION     = "0.49";
 $ATTRIBUTION = "DBD::CSV $DBD::CSV::VERSION by H.Merijn Brand";
 
 $err      = 0;		# holds error code   for DBI::err
@@ -114,6 +114,7 @@ sub init_valid_attributes
 	allow_loose_escapes
 	allow_unquoted_escape
 	always_quote
+	quote_empty
 	quote_space
 	escape_null
 	quote_binary
@@ -223,7 +224,8 @@ sub init_table_meta
 	    exists $dbh->{"csv_$attr"} and $opts{$attr} = $dbh->{"csv_$attr"};
 	    }
 	$dbh->{csv_null} || $meta->{csv_null} and
-	    $opts{blank_is_undef} = $opts{always_quote} = 1;
+	    $opts{Text::CSV_XS->version < 1.18 ? "always_quote" : "quote_empty"} =
+	    $opts{blank_is_undef} = 1;
 
 	my $class = $meta->{csv_class};
 	my $eol   = $meta->{csv_eol};
@@ -525,7 +527,7 @@ and more.  See L<SQL::Statement::Syntax> for a description of the SQL
 syntax supported in DBD::CSV.
 
 Table- and column-names are case insensitive unless quoted. Column names
-will be sanitized unless L</raw_header> is true;
+will be sanitized unless L</raw_header> is true.
 
 =head1 Using DBD::CSV with DBI
 
@@ -1039,6 +1041,18 @@ If you supply an empty array ref, the driver will read the first row
 for you, count the number of columns and create column names like
 C<col0>, C<col1>, ...
 
+Note that column names that match reserved SQL words will cause unwanted
+and sometimes confusing errors. If your CSV has headers that match reserved
+words, you will require these two attributes.
+
+If C<test.csv> looks like
+
+ select,from
+ 1,2
+
+the select query would result in C<select select, from from test;>, which
+obviously is illegal SQL.
+
 =item raw_header
 X<raw_header>
 
@@ -1216,7 +1230,7 @@ Previous maintainer was Jeff Zucker
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by H.Merijn Brand
+Copyright (C) 2009-2016 by H.Merijn Brand
 Copyright (C) 2004-2009 by Jeff Zucker
 Copyright (C) 1998-2004 by Jochen Wiedmann
 
